---
--- Updates ImportedCloudServiceInstance data
---
IF EXISTS(SELECT * FROM sysobjects WHERE xtype = 'P' AND name = 'UpdateImportedCloudServiceInstanceTable')
    DROP PROCEDURE dbo.UpdateImportedCloudServiceInstanceTable
GO
CREATE PROCEDURE dbo.UpdateImportedCloudServiceInstanceTable
                @ComplianceConnectionID INT
AS

	IF OBJECT_ID('tempdb..#DistinctICSI') IS NOT NULL
		DROP TABLE #DistinctICSI
		
	SELECT 
		TOP 1 WITH TIES
		tclsp.ComplianceConnectionID,
		tclsp.ExternalComputerID,
		tclsp.HostID,
		tclsp.HostComputerID,
		tclsp.CloudServiceProvider,
		tclsp.InstanceCloudID,
		tclsp.InstanceAffinity,
		tclsp.ImageID,
		tclsp.LaunchTime,
		tclsp.NetworkID,
		tclsp.MacAddress,
		tclsp.LifecycleMode,
		tclsp.ExpiryTime,
		tclsp.InstanceCount,
		tclsp.OfferingClass,
		tclsp.OfferingType,
		tclsp.[Scope],
		tclsp.Account,
		tclsp.CoreCount,
		tclsp.ThreadsPerCore,
		tclsp.InstanceType,
		tclsp.Region,
		tclsp.AvailabilityZone,
		tclsp.InstanceTenancy,
		tclsp.[VMEnabledStateID],
		tclsp.InventoryDate
	INTO
		#DistinctICSI
	FROM 
		#ImportedCloudServiceInstance as tclsp
	WHERE 
		tclsp.ComplianceConnectionID = @ComplianceConnectionID
	ORDER BY
		ROW_NUMBER() OVER (PARTITION BY tclsp.InstanceCloudID, tclsp.CloudServiceProvider ORDER BY tclsp.InventoryDate DESC)
		
		
	UPDATE
		newData
	SET
		newData.[VMEnabledStateID] = null
	FROM
		#DistinctICSI AS newData
		INNER JOIN dbo.ImportedCloudServiceInstance AS csi
			ON csi.ComplianceConnectionID = newData.ComplianceConnectionID
			AND csi.InstanceCloudID = newData.InstanceCloudID
			AND csi.CloudServiceProvider = newData.CloudServiceProvider
	WHERE
		csi.ComplianceConnectionID = @ComplianceConnectionID
		AND csi.InventoryDate IS NOT NULL
		AND newData.InventoryDate IS NOT NULL
		AND csi.InventoryDate > newData.InventoryDate
		
	DELETE 
	FROM dbo.ImportedCloudServiceInstance
	WHERE
		ComplianceConnectionID = @ComplianceConnectionID
			
	INSERT dbo.ImportedCloudServiceInstance
	SELECT 
		tclsp.ComplianceConnectionID,
		tclsp.ExternalComputerID,
		tclsp.HostID,
		tclsp.HostComputerID,
		tclsp.CloudServiceProvider,
		tclsp.InstanceCloudID,
		tclsp.InstanceAffinity,
		tclsp.ImageID,
		tclsp.LaunchTime,
		tclsp.NetworkID,
		tclsp.MacAddress,
		tclsp.LifecycleMode,
		tclsp.ExpiryTime,
		tclsp.InstanceCount,
		tclsp.OfferingClass,
		tclsp.OfferingType,
		tclsp.[Scope],
		tclsp.Account,
		tclsp.CoreCount,
		tclsp.ThreadsPerCore,
		tclsp.InstanceType,
		tclsp.Region,
		tclsp.AvailabilityZone,
		tclsp.InstanceTenancy,
		tclsp.[VMEnabledStateID],
		tclsp.InventoryDate
	FROM 
		#DistinctICSI as tclsp
					
	IF OBJECT_ID('tempdb..#ImportedCloudServiceInstance') IS NOT NULL
		DROP TABLE #ImportedCloudServiceInstance     
		
	IF OBJECT_ID('tempdb..#DistinctICSI') IS NOT NULL
		DROP TABLE #DistinctICSI
GO